<?php

/**
 * This file implements the Table of content plugin.
 *
 * For the most recent and complete Plugin API documentation
 * see {@link Plugin} in ../inc/plugins/_plugin.class.php.
 *
 * This file is part of the evoCore framework - {@link http://evocore.net/}
 * See also {@link https://github.com/b2evolution/b2evolution}.
 *
 * @license GNU GPL v2 - {@link http://b2evolution.net/about/gnu-gpl-license}
 *
 * @copyright (c)2003-2016 by Francois Planque - {@link http://fplanque.com/}
 * Parts of this file are copyright (c)2004-2006 by Daniel HAHLER - {@link http://thequod.de/contact}.
 *
 * @package plugins
 */
if (!defined('EVO_MAIN_INIT'))
	die('Please, do not access this page directly.');

/**
 * Table of content Plugin
 *
 * This plugin responds to virtually all possible plugin events :P
 *
 * @package plugins
 */
class tableofcontent_plugin extends Plugin {

	/**
	 * Variables below MUST be overriden by plugin implementations,
	 * either in the subclass declaration or in the subclass constructor.
	 */
	var $name = 'Table of content';
	var $code = 'evo_tableofcontent';
	var $group = 'rendering';
	var $short_desc;
	var $long_desc;
	var $priority = 99;
	var $number_of_installs = 1;
	var $version = '0.1';

	/**
	 * Init
	 *
	 * This gets called after a plugin has been registered/instantiated.
	 */
	function PluginInit(& $params) {
		$this->short_desc = T_('Table of post content plugin');
		$this->long_desc = T_('This would make the table of the post content by the html tag h1 to h6.');
	}

	/**
	 * Define here default collection/blog settings that are to be made available in the backoffice.
	 *
	 * @param array Associative array of parameters.
	 * @return array See {@link Plugin::get_coll_setting_definitions()}.
	 */
	function get_coll_setting_definitions(& $params) {
		$default_params = array_merge($params, array(
		    'default_post_rendering' => 'opt-out',
		    'default_comment_rendering' => 'never'
		));
		return parent::get_coll_setting_definitions($default_params);
	}

	/**
	 * Event handler: Called at the beginning of the skin's HTML HEAD section.
	 *
	 * Use this to add any HTML HEAD lines (like CSS styles or links to resource files (CSS, JavaScript, ..)).
	 *
	 * @see Plugin::SkinBeginHtmlHead()
	 * @param array Associative array of parameters
	 */
	function SkinBeginHtmlHead(& $params) {
		$this->require_js('js/tableofcontent.js');
	}

	/**
	 * Generate random string
	 * 
	 * @param int $length String length
	 * @return string
	 */
	function random_str($length) {
		$arr = array_merge(range('a', 'z'), range('A', 'Z'));
		$str = '';
		$arr_len = count($arr);
		for ($i = 0; $i < $length; $i++) {
			$rand = mt_rand(0, $arr_len - 1);
			$str.=$arr[$rand];
		}
		return $str;
	}

	/**
	 * Event handler: Called when rendering item/post contents as HTML. (CACHED)
	 *
	 * The rendered content will be *cached* and the cached content will be reused on subsequent displays.
	 * Use {@link DisplayItemAsHtml()} instead if you want to do rendering at display time.
	 *
	 * Note: You have to change $params['data'] (which gets passed by reference).
	 *
	 * @see Plugin::DisplayItemAsHtml()
	 * @param array Associative array of parameters
	 *   - 'data': the data (by reference). You probably want to modify this.
	 *   - 'format': see {@link format_to_output()}. Only 'htmlbody' and 'entityencoded' will arrive here.
	 *   - 'Item': the {@link Item} object which gets rendered.
	 *   - 'view_type': What part of a post are we displaying: 'teaser', 'extension' or 'full'
	 * @return boolean Have we changed something?
	 */
	function RenderItemAsHtml(& $params) {
		global $Item;
		$page_url = is_object($Item) ? $Item->get_permanent_url() : '';
//		if(is_object($Item)){
//			$Item-> get_content_teaser();
//		}
		$content_id = $this->random_str(5);
		$script = "<script>$(document).ready(function() {buildCTable('" . $content_id . "','" . $page_url . "');});</script>";
		$params['data'] = "<div id='" . $content_id . "'>" . $params['data'] . "</div>" . $script;

		return true;
	}

}

?>